//
//  MainController.m
//  ButtonBarTest
//
//  Created by Andreas on 09.02.07.
//  Copyright 2007 Andreas Mayer. All rights reserved.
//
//  2010-02-18  Andreas Mayer
//  - use NSGradient instead of CTGradient for 10.5 and above


#import "MainController.h"
#import "AMButtonBar.h"
#import "AMButtonBarItem.h"
#if defined(MAC_OS_X_VERSION_10_5) && (MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_5)
#import "NSGradient_AMButtonBar.h"
#else
#import "CTGradient.h"
#import "CTGradient_AMButtonBar.h"
#endif

@interface MainController (Private)
- (void)log:(NSString *)string;
@end


@implementation MainController

- (IBAction)changeGradient:(id)sender
{
#if defined(MAC_OS_X_VERSION_10_5) && (MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_5)
	if ([(NSMatrix *)sender selectedRow] == 1) {
		[buttonBar setBackgroundGradient:[NSGradient blueButtonBarGradient]];
	} else {
		[buttonBar setBackgroundGradient:[NSGradient grayButtonBarGradient]];
	}
#else
	if ([(NSMatrix *)sender selectedRow] == 1) {
		[buttonBar setBackgroundGradient:[CTGradient blueButtonBarGradient]];
	} else {
		[buttonBar setBackgroundGradient:[CTGradient grayButtonBarGradient]];
	}
#endif
	[buttonBar setNeedsDisplay:YES];
}

- (IBAction)changeShowBaselineSeparator:(id)sender
{
	[buttonBar setShowsBaselineSeparator:([sender state] == NSOnState)];
	[buttonBar setNeedsDisplay:YES];
}

- (IBAction)changeAllowMultipleSelection:(id)sender;
{
	[buttonBar setAllowsMultipleSelection:([sender state] == NSOnState)];
}

- (void)awakeFromNib
{
	AMButtonBarItem *item = [[[AMButtonBarItem alloc] initWithIdentifier:@"title"] autorelease];
	[item setTitle:@"Title"];
	[buttonBar insertItem:item atIndex:0];
	item = [[[AMButtonBarItem alloc] initWithIdentifier:@"artist"] autorelease];
	[item setTitle:@"Artist"];
	[item setEnabled:NO];
	[buttonBar insertItem:item atIndex:1];
	item = [[[AMButtonBarItem alloc] initWithIdentifier:@"album"] autorelease];
	[item setTitle:@"Album"];
	[buttonBar insertItem:item atIndex:2];
	item = [[[AMButtonBarItem alloc] initWithIdentifier:@"sep1"] autorelease];
	[item setSeparatorItem:YES];
	[buttonBar insertItem:item atIndex:3];
	item = [[[AMButtonBarItem alloc] initWithIdentifier:@"rating"] autorelease];
	[item setTitle:@"Rating"];
	[buttonBar insertItem:item atIndex:4];
	[buttonBar setNeedsDisplay:YES];
	[buttonBar setDelegate:self];
}

- (void)buttonBarSelectionDidChange:(NSNotification *)aNotification
{
	NSString *selectedItems = [[aNotification userInfo] objectForKey:@"selectedItems"];
	[self log:[NSString stringWithFormat:@"selection did change: %@", selectedItems]];
}

- (void)log:(NSString *)string
{
	NSTextStorage *textStorage = [logView textStorage];
	[textStorage replaceCharactersInRange:NSMakeRange([textStorage length], 0) withString:string];
	[textStorage replaceCharactersInRange:NSMakeRange([textStorage length], 0) withString:@"\r"];
}


@end
